# movies = ["The Holy Grail", "The Life of Brian", "The Meaning of Life"]
# movies.insert(1,1975);
# movies.insert(3, 1979);
# movies.insert(5, 1983);
# # print(movies);
#
# movies = ['The Holy Grail', 1975, 'Terry Jones & Terry Gilliam', 91, ['Graham Chapman', ['Michael Palin',
# 'John Cleese', 'Terry Gilliam', 'Eric Idle', 'Terry Jones']]]
#
# cute_mom = [
#     "Mengfei Yang",
#     30.75,
#     True,
#     ["Pink", "Coffee","Lovely"]
# ]

def traverse_list(list_par, level):
    if isinstance(list_par, list):
        for list_item in list_par:
            traverse_list(list_item, level+1)
    else:
        indent="";
        for time in range(level):
            # indent += "\t"
            print(end="\t")
        print(indent+str(list_par))


from distutils.core import setup

setup(
    name='my_traverse',
    version='1.0.1',
    py_modules=['nester'],
    author='Bill',
    author_email='bill@gmail.com',
    url='http://www.python.org',
    description='A simple printer of nested lists',
)